---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
<-- A clear and concise description of what the bug is. -->

**Expected behavior**
<-- A clear and concise description of what you expected to happen. -->

**To Reproduce**
<-- Describe the steps to reproduce the behavior. -->

**Environment information**
* Output of `zhmc --version`:
* HMC version:

**Command output**
<-- The zhmc command and relevant parts of the command output (including stderr). If possible, with '--log all=debug'. -->
